@@ -1,4 +1,9 @@
-from higlass.viewer import view, display
+from ._version import __version__
+from .viewer import view, display
+from .tilesets import Tileset
+from .server import Server
+from .client import Track, CombinedTrack, View, ViewConf
+
 
 def _jupyter_nbextension_paths():
     return [{
@@ -7,5 +12,3 @@ def _jupyter_nbextension_paths():
         'dest': 'higlass-jupyter',
         'require': 'higlass-jupyter/extension'
     }]
-
-from ._version import __version__
