@@ -1,8 +1,20 @@
 from copy import deepcopy
-import warnings
 import json
 import slugid
-import sys
+import logging
+import os
+
+
+logger = logging.getLogger()
+fhandler = logging.FileHandler(filename='higlass-python.log', mode='a')
+formatter = logging.Formatter('[%(asctime)s] %(levelname)s in %(module)s: %(message)s')
+fhandler.setFormatter(formatter)
+logger.addHandler(fhandler)
+
+if 'HIGLASS_PYTHON_DEBUG' in os.environ and os.environ['HIGLASS_PYTHON_DEBUG']:
+    logger.setLevel(logging.DEBUG)
+else:
+    logger.setLevel(logging.ERROR)
 
 
 __all__ = ['Track', 'CombinedTrack', 'View', 'ViewConf']
@@ -100,6 +112,21 @@ class Track(Component):
 
         self.conf.update(kwargs)
 
+        if "uid" not in self.conf:
+            self.conf["uid"] = slugid.nice()
+
+    @property
+    def uid(self):
+        return self.conf["uid"]
+
+    @property
+    def options(self):
+        return self.conf["options"]
+
+    @property
+    def type(self):
+        return self.conf["type"]
+
     def change_attributes(self, **kwargs):
         '''
         Change an attribute of this track and return a new copy.
@@ -217,7 +244,10 @@ class View(Component):
         for track in tracks:
             self.add_track(track)
 
-        for overlay in overlays:
+        for i, overlay in enumerate(overlays):
+            # The uids need to be unique so if no uid is available we need to
+            # define a unique uid before calling `self.add_overlay`.
+            overlay["uid"] = overlay.get("uid", "overlay-{}".format(i))
             self.add_overlay(overlay)
 
     @property
@@ -238,12 +268,11 @@ class View(Component):
             we fall back on a default position if the track type has one.
 
         """
-        track_type = track.conf['type']
         if position is None:
             if track.position is not None:
                 position = track.position
-            elif track_type in _track_default_position:
-                position = _track_default_position[track_type]
+            elif track.type in _track_default_position:
+                position = _track_default_position[track.type]
             else:
                 raise ValueError('A track position is required.')
         self._track_position[track] = position
@@ -298,9 +327,9 @@ class View(Component):
         try:
             options = overlay.get("options", {})
             overlay_conf = {
-                "uid": "overlay",
-                "includes": overlay["includes"],
-                "type": "",
+                "uid": overlay.get("uid", "overlay"),
+                "includes": overlay.get("includes", []),
+                "type": overlay.get("type", ""),
                 "options": {
                     "extent": overlay.get("extent", [])
                 }
@@ -314,13 +343,14 @@ class View(Component):
 class ViewConf(Component):
     """Configure a dashboard"""
 
-    def __init__(self, views=[], location_syncs=[], zoom_syncs=[]):
+    def __init__(self, views=[], location_syncs=[], value_scale_syncs=[], zoom_syncs=[]):
 
         self.conf = {
             "editable": True,
             "views": [],
             "trackSourceServers": ["http://higlass.io/api/v1"],
             "locationLocks": {"locksByViewUid": {}, "locksDict": {}},
+            "valueScaleLocks": {"locksByViewUid": {}, "locksDict": {}},
             "zoomLocks": {"locksByViewUid": {}, "locksDict": {}},
             "exportViewUrl": "http://higlass.io/api/v1/viewconfs",
         }
@@ -333,6 +363,9 @@ class ViewConf(Component):
         for location_sync in location_syncs:
             self.add_location_sync(location_sync)
 
+        for value_scale_sync in value_scale_syncs:
+            self.add_value_scale_sync(value_scale_sync)
+
         for zoom_sync in zoom_syncs:
             self.add_zoom_sync(zoom_sync)
 
@@ -340,6 +373,49 @@ class ViewConf(Component):
     def views(self):
         return list(self._views_by_id.values())
 
+    @property
+    def default_view(self):
+        """Default view of the view config
+
+        The default view equals the first view if only one view exist.
+
+        Returns:
+            View -- View instance or ``None`` if more than one view exists.
+        """
+        if len(self.views) == 1:
+            return self.views[0]
+        return None
+
+    def _combine_view_track_uid(self, view_uid, track_uid):
+        return f"{view_uid}.{track_uid}"
+
+    def _extract_view_track_uids(self, definition):
+        if isinstance(definition, tuple):
+            # definition is a tuple of a view and a track instance
+            view_uid = definition[0].uid
+            track_uid = definition[1].uid
+        elif isinstance(definition, Track):
+            # definition is a track instance which assumes that only one view
+            # exists
+            track_uid = definition.uid
+        elif isinstance(definition, str):
+            # definition is a string
+            uids = definition.split(".")
+            if len(uids) == 2:
+                view_uid, track_uid = uids
+            else:
+                track_uid = uids[0]
+        else:
+            logger.warning("Could not extract view and track UID")
+            track_uid = None
+            view_uid = None
+
+        if self.default_view is not None:
+            logger.info("Default view is used")
+            view_uid = self.default_view.uid
+
+        return view_uid, track_uid
+
     def _add_sync(self, lock_group, lock_id, view_uids):
         for view_uid in view_uids:
             if lock_id not in self.conf[lock_group]['locksDict']:
@@ -357,6 +433,27 @@ class ViewConf(Component):
         # TODO: check that view already exists in viewconf
         self._add_sync("locationLocks", lock_id, [v.uid for v in views_to_sync])
 
+    def add_value_scale_sync(self, tracks_to_sync):
+        locks_map = self.conf["valueScaleLocks"]["locksByViewUid"]
+        locks_dict = self.conf["valueScaleLocks"]["locksDict"]
+        lock_id = slugid.nice()
+
+        for definition in tracks_to_sync:
+            v_uid, t_uid = self._extract_view_track_uids(definition)
+
+            if v_uid is None or t_uid is None:
+                # If no view UID is found the definition seems to be broken
+                logger.warning("View or track definition is broken")
+                continue
+
+            vt_uid = self._combine_view_track_uid(v_uid, t_uid)
+
+            if lock_id not in locks_dict:
+                locks_dict[lock_id] = {}
+
+            locks_dict[lock_id][vt_uid] = { "view": v_uid, "track": t_uid }
+            locks_map[vt_uid] = lock_id
+
     def add_view(self, view):
         """
         Add a new view
@@ -416,6 +513,10 @@ class ViewConf(Component):
         for lock_id, attrs in locks.items():
             self._add_sync('locationLocks', lock_id, attrs.keys())
 
+        locks = conf.get('valueScaleLocks', {}).get('locksDict', {})
+        for lock_id, attrs in locks.items():
+            self._add_sync('valueScaleLocks', lock_id, attrs.keys())
+
         locks = conf.get('zoomLocks', {}).get('locksDict', {})
         for lock, attrs in locks.items():
             self._add_sync('zoomLocks', lock_id, attrs.keys())
